.. SPDX-FileCopyrightText: 2024 Anna <cyber@sysrq.in>
.. SPDX-License-Identifier: CC0-1.0

Imaginary FAQ
=============

.. contents::
   :local:

Can this library be replaced by ``requests.get()``?
---------------------------------------------------

Yes, if your search never results in >200 packages.

Why asynchronous?
-----------------

It's what cool kids use nowadays.

Oh, so will you rewrite it in Rust?
-----------------------------------

No, the library is pure Python and will always stay. Although its dependencies
are guaranteed to depend on Rust.

What version policy does the library follow?
--------------------------------------------

`SemVer 2.0.0 <https://semver.org/spec/v2.0.0.html>`_.

What is that EUPL license about? I've never seen it before.
-----------------------------------------------------------

It's like LGPL but much shorter and understandable.
